@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -93,6 +93,10 @@ void create<LoadCommand>(nb::module_& m) {
     .value(PY_ENUM(LoadCommand::TYPE::DYLD_EXPORTS_TRIE))
     .value(PY_ENUM(LoadCommand::TYPE::DYLD_CHAINED_FIXUPS))
     .value(PY_ENUM(LoadCommand::TYPE::FILESET_ENTRY))
+    .value(PY_ENUM(LoadCommand::TYPE::ATOM_INFO))
+    .value(PY_ENUM(LoadCommand::TYPE::FUNCTION_VARIANTS))
+    .value(PY_ENUM(LoadCommand::TYPE::FUNCTION_VARIANT_FIXUPS))
+    .value(PY_ENUM(LoadCommand::TYPE::TARGET_TRIPLE))
     .value(PY_ENUM(LoadCommand::TYPE::LIEF_UNKNOWN))
   #undef PY_ENUM
   ;
