@@ -7,16 +7,33 @@ template<>
 void create<LIEF::assembly::riscv::REG>(nb::module_& m) {
   nb::enum_<LIEF::assembly::riscv::REG> reg(m, "REG");
   reg.value("NoRegister", LIEF::assembly::riscv::REG::NoRegister)
+  .value("FCSR", LIEF::assembly::riscv::REG::FCSR)
   .value("FFLAGS", LIEF::assembly::riscv::REG::FFLAGS)
   .value("FRM", LIEF::assembly::riscv::REG::FRM)
+  .value("SF_VCIX_STATE", LIEF::assembly::riscv::REG::SF_VCIX_STATE)
   .value("SSP", LIEF::assembly::riscv::REG::SSP)
-  .value("VCIX_STATE", LIEF::assembly::riscv::REG::VCIX_STATE)
   .value("VL", LIEF::assembly::riscv::REG::VL)
   .value("VLENB", LIEF::assembly::riscv::REG::VLENB)
   .value("VTYPE", LIEF::assembly::riscv::REG::VTYPE)
   .value("VXRM", LIEF::assembly::riscv::REG::VXRM)
   .value("VXSAT", LIEF::assembly::riscv::REG::VXSAT)
   .value("DUMMY_REG_PAIR_WITH_X0", LIEF::assembly::riscv::REG::DUMMY_REG_PAIR_WITH_X0)
+  .value("T0", LIEF::assembly::riscv::REG::T0)
+  .value("T1", LIEF::assembly::riscv::REG::T1)
+  .value("T2", LIEF::assembly::riscv::REG::T2)
+  .value("T3", LIEF::assembly::riscv::REG::T3)
+  .value("T4", LIEF::assembly::riscv::REG::T4)
+  .value("T5", LIEF::assembly::riscv::REG::T5)
+  .value("T6", LIEF::assembly::riscv::REG::T6)
+  .value("T7", LIEF::assembly::riscv::REG::T7)
+  .value("T8", LIEF::assembly::riscv::REG::T8)
+  .value("T9", LIEF::assembly::riscv::REG::T9)
+  .value("T10", LIEF::assembly::riscv::REG::T10)
+  .value("T11", LIEF::assembly::riscv::REG::T11)
+  .value("T12", LIEF::assembly::riscv::REG::T12)
+  .value("T13", LIEF::assembly::riscv::REG::T13)
+  .value("T14", LIEF::assembly::riscv::REG::T14)
+  .value("T15", LIEF::assembly::riscv::REG::T15)
   .value("V0", LIEF::assembly::riscv::REG::V0)
   .value("V1", LIEF::assembly::riscv::REG::V1)
   .value("V2", LIEF::assembly::riscv::REG::V2)
@@ -177,7 +194,103 @@ void create<LIEF::assembly::riscv::REG>(nb::module_& m) {
   .value("F29_H", LIEF::assembly::riscv::REG::F29_H)
   .value("F30_H", LIEF::assembly::riscv::REG::F30_H)
   .value("F31_H", LIEF::assembly::riscv::REG::F31_H)
+  .value("F0_Q", LIEF::assembly::riscv::REG::F0_Q)
+  .value("F1_Q", LIEF::assembly::riscv::REG::F1_Q)
+  .value("F2_Q", LIEF::assembly::riscv::REG::F2_Q)
+  .value("F3_Q", LIEF::assembly::riscv::REG::F3_Q)
+  .value("F4_Q", LIEF::assembly::riscv::REG::F4_Q)
+  .value("F5_Q", LIEF::assembly::riscv::REG::F5_Q)
+  .value("F6_Q", LIEF::assembly::riscv::REG::F6_Q)
+  .value("F7_Q", LIEF::assembly::riscv::REG::F7_Q)
+  .value("F8_Q", LIEF::assembly::riscv::REG::F8_Q)
+  .value("F9_Q", LIEF::assembly::riscv::REG::F9_Q)
+  .value("F10_Q", LIEF::assembly::riscv::REG::F10_Q)
+  .value("F11_Q", LIEF::assembly::riscv::REG::F11_Q)
+  .value("F12_Q", LIEF::assembly::riscv::REG::F12_Q)
+  .value("F13_Q", LIEF::assembly::riscv::REG::F13_Q)
+  .value("F14_Q", LIEF::assembly::riscv::REG::F14_Q)
+  .value("F15_Q", LIEF::assembly::riscv::REG::F15_Q)
+  .value("F16_Q", LIEF::assembly::riscv::REG::F16_Q)
+  .value("F17_Q", LIEF::assembly::riscv::REG::F17_Q)
+  .value("F18_Q", LIEF::assembly::riscv::REG::F18_Q)
+  .value("F19_Q", LIEF::assembly::riscv::REG::F19_Q)
+  .value("F20_Q", LIEF::assembly::riscv::REG::F20_Q)
+  .value("F21_Q", LIEF::assembly::riscv::REG::F21_Q)
+  .value("F22_Q", LIEF::assembly::riscv::REG::F22_Q)
+  .value("F23_Q", LIEF::assembly::riscv::REG::F23_Q)
+  .value("F24_Q", LIEF::assembly::riscv::REG::F24_Q)
+  .value("F25_Q", LIEF::assembly::riscv::REG::F25_Q)
+  .value("F26_Q", LIEF::assembly::riscv::REG::F26_Q)
+  .value("F27_Q", LIEF::assembly::riscv::REG::F27_Q)
+  .value("F28_Q", LIEF::assembly::riscv::REG::F28_Q)
+  .value("F29_Q", LIEF::assembly::riscv::REG::F29_Q)
+  .value("F30_Q", LIEF::assembly::riscv::REG::F30_Q)
+  .value("F31_Q", LIEF::assembly::riscv::REG::F31_Q)
+  .value("X0_H", LIEF::assembly::riscv::REG::X0_H)
+  .value("X1_H", LIEF::assembly::riscv::REG::X1_H)
+  .value("X2_H", LIEF::assembly::riscv::REG::X2_H)
+  .value("X3_H", LIEF::assembly::riscv::REG::X3_H)
+  .value("X4_H", LIEF::assembly::riscv::REG::X4_H)
+  .value("X5_H", LIEF::assembly::riscv::REG::X5_H)
+  .value("X6_H", LIEF::assembly::riscv::REG::X6_H)
+  .value("X7_H", LIEF::assembly::riscv::REG::X7_H)
+  .value("X8_H", LIEF::assembly::riscv::REG::X8_H)
+  .value("X9_H", LIEF::assembly::riscv::REG::X9_H)
+  .value("X10_H", LIEF::assembly::riscv::REG::X10_H)
+  .value("X11_H", LIEF::assembly::riscv::REG::X11_H)
+  .value("X12_H", LIEF::assembly::riscv::REG::X12_H)
+  .value("X13_H", LIEF::assembly::riscv::REG::X13_H)
+  .value("X14_H", LIEF::assembly::riscv::REG::X14_H)
+  .value("X15_H", LIEF::assembly::riscv::REG::X15_H)
+  .value("X16_H", LIEF::assembly::riscv::REG::X16_H)
+  .value("X17_H", LIEF::assembly::riscv::REG::X17_H)
+  .value("X18_H", LIEF::assembly::riscv::REG::X18_H)
+  .value("X19_H", LIEF::assembly::riscv::REG::X19_H)
+  .value("X20_H", LIEF::assembly::riscv::REG::X20_H)
+  .value("X21_H", LIEF::assembly::riscv::REG::X21_H)
+  .value("X22_H", LIEF::assembly::riscv::REG::X22_H)
+  .value("X23_H", LIEF::assembly::riscv::REG::X23_H)
+  .value("X24_H", LIEF::assembly::riscv::REG::X24_H)
+  .value("X25_H", LIEF::assembly::riscv::REG::X25_H)
+  .value("X26_H", LIEF::assembly::riscv::REG::X26_H)
+  .value("X27_H", LIEF::assembly::riscv::REG::X27_H)
+  .value("X28_H", LIEF::assembly::riscv::REG::X28_H)
+  .value("X29_H", LIEF::assembly::riscv::REG::X29_H)
+  .value("X30_H", LIEF::assembly::riscv::REG::X30_H)
+  .value("X31_H", LIEF::assembly::riscv::REG::X31_H)
   .value("X0_Pair", LIEF::assembly::riscv::REG::X0_Pair)
+  .value("X0_W", LIEF::assembly::riscv::REG::X0_W)
+  .value("X1_W", LIEF::assembly::riscv::REG::X1_W)
+  .value("X2_W", LIEF::assembly::riscv::REG::X2_W)
+  .value("X3_W", LIEF::assembly::riscv::REG::X3_W)
+  .value("X4_W", LIEF::assembly::riscv::REG::X4_W)
+  .value("X5_W", LIEF::assembly::riscv::REG::X5_W)
+  .value("X6_W", LIEF::assembly::riscv::REG::X6_W)
+  .value("X7_W", LIEF::assembly::riscv::REG::X7_W)
+  .value("X8_W", LIEF::assembly::riscv::REG::X8_W)
+  .value("X9_W", LIEF::assembly::riscv::REG::X9_W)
+  .value("X10_W", LIEF::assembly::riscv::REG::X10_W)
+  .value("X11_W", LIEF::assembly::riscv::REG::X11_W)
+  .value("X12_W", LIEF::assembly::riscv::REG::X12_W)
+  .value("X13_W", LIEF::assembly::riscv::REG::X13_W)
+  .value("X14_W", LIEF::assembly::riscv::REG::X14_W)
+  .value("X15_W", LIEF::assembly::riscv::REG::X15_W)
+  .value("X16_W", LIEF::assembly::riscv::REG::X16_W)
+  .value("X17_W", LIEF::assembly::riscv::REG::X17_W)
+  .value("X18_W", LIEF::assembly::riscv::REG::X18_W)
+  .value("X19_W", LIEF::assembly::riscv::REG::X19_W)
+  .value("X20_W", LIEF::assembly::riscv::REG::X20_W)
+  .value("X21_W", LIEF::assembly::riscv::REG::X21_W)
+  .value("X22_W", LIEF::assembly::riscv::REG::X22_W)
+  .value("X23_W", LIEF::assembly::riscv::REG::X23_W)
+  .value("X24_W", LIEF::assembly::riscv::REG::X24_W)
+  .value("X25_W", LIEF::assembly::riscv::REG::X25_W)
+  .value("X26_W", LIEF::assembly::riscv::REG::X26_W)
+  .value("X27_W", LIEF::assembly::riscv::REG::X27_W)
+  .value("X28_W", LIEF::assembly::riscv::REG::X28_W)
+  .value("X29_W", LIEF::assembly::riscv::REG::X29_W)
+  .value("X30_W", LIEF::assembly::riscv::REG::X30_W)
+  .value("X31_W", LIEF::assembly::riscv::REG::X31_W)
   .value("V0M2", LIEF::assembly::riscv::REG::V0M2)
   .value("V0M4", LIEF::assembly::riscv::REG::V0M4)
   .value("V0M8", LIEF::assembly::riscv::REG::V0M8)
@@ -192,8 +305,8 @@ void create<LIEF::assembly::riscv::REG>(nb::module_& m) {
   .value("V12M2", LIEF::assembly::riscv::REG::V12M2)
   .value("V12M4", LIEF::assembly::riscv::REG::V12M4)
   .value("V14M2", LIEF::assembly::riscv::REG::V14M2)
-  .value("V16M2", LIEF::assembly::riscv::REG::V16M2)
-  .value("V16M4", LIEF::assembly::riscv::REG::V16M4)
+  .value("V16M2", LIEF::assembly::riscv::REG::V16M2);
+  reg.value("V16M4", LIEF::assembly::riscv::REG::V16M4)
   .value("V16M8", LIEF::assembly::riscv::REG::V16M8)
   .value("V18M2", LIEF::assembly::riscv::REG::V18M2)
   .value("V20M2", LIEF::assembly::riscv::REG::V20M2)
@@ -305,8 +418,8 @@ void create<LIEF::assembly::riscv::REG>(nb::module_& m) {
   .value("V29_V30_V31", LIEF::assembly::riscv::REG::V29_V30_V31)
   .value("V0_V1_V2", LIEF::assembly::riscv::REG::V0_V1_V2)
   .value("V2M2_V4M2_V6M2", LIEF::assembly::riscv::REG::V2M2_V4M2_V6M2)
-  .value("V4M2_V6M2_V8M2", LIEF::assembly::riscv::REG::V4M2_V6M2_V8M2);
-  reg.value("V6M2_V8M2_V10M2", LIEF::assembly::riscv::REG::V6M2_V8M2_V10M2)
+  .value("V4M2_V6M2_V8M2", LIEF::assembly::riscv::REG::V4M2_V6M2_V8M2)
+  .value("V6M2_V8M2_V10M2", LIEF::assembly::riscv::REG::V6M2_V8M2_V10M2)
   .value("V8M2_V10M2_V12M2", LIEF::assembly::riscv::REG::V8M2_V10M2_V12M2)
   .value("V10M2_V12M2_V14M2", LIEF::assembly::riscv::REG::V10M2_V12M2_V14M2)
   .value("V12M2_V14M2_V16M2", LIEF::assembly::riscv::REG::V12M2_V14M2_V16M2)
