@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@
 
 #include <nanobind/stl/string.h>
 #include <nanobind/stl/vector.h>
+#include <nanobind/extra/memoryview.hpp>
 
 #include "LIEF/utils.hpp"
 #include "LIEF/hash.hpp"
@@ -69,6 +70,10 @@
   #include "ART/init.hpp"
 #endif
 
+#if defined(LIEF_COFF_SUPPORT)
+  #include "COFF/init.hpp"
+#endif
+
 
 nb::module_* lief_mod = nullptr;
 
@@ -109,19 +114,19 @@ void init_logger(nb::module_& m) {
     .value(PY_ENUM(logging::LEVEL::INFO));
   #undef PY_ENUM
 
-  logging.def("disable", &logging::disable,
+  logging.def("disable", nb::overload_cast<>(&logging::disable),
               "Disable the logger globally"_doc);
 
-  logging.def("enable", &logging::enable,
+  logging.def("enable", nb::overload_cast<>(&logging::enable),
               "Enable the logger globally"_doc);
 
-  logging.def("set_level", &logging::set_level,
+  logging.def("set_level", nb::overload_cast<logging::LEVEL>(&logging::set_level),
               "Change logging level", "level"_a);
 
-  logging.def("get_level", &logging::get_level,
+  logging.def("get_level", nb::overload_cast<>(&logging::get_level),
               "Get current logging level");
 
-  logging.def("set_path", &logging::set_path,
+  logging.def("set_path", nb::overload_cast<const std::string&>(&logging::set_path),
               "Change the logger as a file-base logging and set its path"_doc,
               "path"_a);
 
@@ -150,7 +155,7 @@ void init_logger(nb::module_& m) {
               static_cast<void(*)(const std::string&)>(&logging::critical),
               "Log an :attr:`~.LEVEL.CRITICAL` message"_doc, "msg"_a);
 
-  logging.def("enable_debug", &logging::enable_debug,
+  logging.def("enable_debug", nb::overload_cast<>(&logging::enable_debug),
               "Enable :attr:`~.LEVEL.DEBUG` log level"_doc);
 
   logging.def("reset", [] {
@@ -217,6 +222,24 @@ void init(nb::module_& m) {
   m.attr("__is_tagged__") = bool(LIEF_TAGGED);
   m.doc() = "LIEF Python API";
 
+  nb::class_<LIEF::lief_version_t>(m, "lief_version_t")
+    .def_rw("major", &LIEF::lief_version_t::major)
+    .def_rw("minor", &LIEF::lief_version_t::minor)
+    .def_rw("patch", &LIEF::lief_version_t::patch)
+    .def_rw("id",    &LIEF::lief_version_t::id)
+    .def("__repr__",
+      [] (const LIEF::lief_version_t& version) {
+        return fmt::format("<lief_version_t: {}>", version.to_string());
+      }
+    )
+    .def("__str__",
+      [] (const LIEF::lief_version_t& version) {
+         return version.to_string();
+      }
+    )
+  ;
+
+
   m.def("disable_leak_warning", [] {
     nb::set_leak_warnings(false);
   }, R"doc(
@@ -250,6 +273,31 @@ void init(nb::module_& m) {
     "mangled"_a
   );
 
+  m.def("dump", [] (nb::memoryview view, const std::string& title,
+                    const std::string& prefix, size_t limit)
+    {
+      return LIEF::dump(view.data(), view.size(), title, prefix, limit);
+    }, "buffer"_a, "title"_a = "", "prefix"_a = "", "limit"_a = 0,
+    R"doc(
+    Hexdump the provided buffer:
+
+    .. code-block:: text
+
+      +---------------------------------------------------------------------+
+      | 88 56 05 00 00 00 00 00 00 00 00 00 22 58 05 00  | .V.........."X.. |
+      | 10 71 02 00 78 55 05 00 00 00 00 00 00 00 00 00  | .q..xU.......... |
+      | 68 5c 05 00 00 70 02 00 00 00 00 00 00 00 00 00  | h\...p.......... |
+      | 00 00 00 00 00 00 00 00 00 00 00 00              | ............     |
+      +---------------------------------------------------------------------+
+    )doc"_doc
+  );
+
+  m.def("extended_version_info", &LIEF::extended_version_info,
+        "Details about the extended version"_doc);
+
+  m.def("extended_version", &LIEF::extended_version,
+        "Return the extended version"_doc);
+
   LIEF::py::init_extension(m);
 
   LIEF::py::init_python_sink();
@@ -263,13 +311,14 @@ void init(nb::module_& m) {
   LIEF::py::init_hash(m);
   LIEF::py::init_json(m);
 
+  LIEF::assembly::py::init(m);
+
   LIEF::py::init_abstract(m);
 
   LIEF::dwarf::py::init(m);
   LIEF::pdb::py::init(m);
   LIEF::objc::py::init(m);
   LIEF::dsc::py::init(m);
-  LIEF::assembly::py::init(m);
 
 #if defined(LIEF_ELF_SUPPORT)
   LIEF::ELF::py::init(m);
@@ -299,6 +348,10 @@ void init(nb::module_& m) {
   LIEF::ART::py::init(m);
 #endif
 
+#if defined(LIEF_COFF_SUPPORT)
+  LIEF::COFF::py::init(m);
+#endif
+
 }
 
 }
