@@ -26,7 +26,7 @@
 //! # For nightly
 //! lief = { git = "https://github.com/lief-project/LIEF", branch = "main" }
 //! # For releases
-//! lief = 0.16.6
+//! lief = 0.17.0
 //! ```
 //!
 //! ```rust
@@ -43,6 +43,9 @@
 //!        Some(lief::Binary::MachO(macho)) => {
 //!            // Process Mach-O file (including FatMachO)
 //!        },
+//!        Some(lief::Binary::COFF(coff)) => {
+//!            // Process coff file
+//!        },
 //!        None => {
 //!            // Parsing error
 //!        }
@@ -70,6 +73,8 @@ pub mod macho;
 
 pub mod pe;
 
+pub mod coff;
+
 pub mod pdb;
 
 pub mod dwarf;
@@ -97,7 +102,7 @@ mod debug_location;
 pub use binary::Binary;
 
 #[doc(inline)]
-pub use generic::Relocation;
+pub use generic::{Relocation, Function};
 
 #[doc(inline)]
 pub use error::Error;
@@ -111,6 +116,19 @@ pub use range::Range;
 #[doc(inline)]
 pub use debug_location::DebugLocation;
 
+pub struct Version {
+    pub major: u64,
+    pub minor: u64,
+    pub patch: u64,
+    pub id: u64,
+}
+
+impl std::fmt::Display for Version {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        write!(f, "{}.{}.{}.{}", self.major, self.minor, self.patch, self.id)
+    }
+}
+
 /// Whether it is an extended version of LIEF
 pub fn is_extended() -> bool {
     lief_ffi::is_extended()
@@ -121,6 +139,24 @@ pub fn extended_version_info() -> String {
     lief_ffi::extended_version_info().to_string()
 }
 
+/// Return the extended version
+pub fn extended_version() -> Version {
+    let ffi_version = lief_ffi::extended_version();
+    Version {
+        major: ffi_version.major, minor: ffi_version.minor,
+        patch: ffi_version.patch, id: ffi_version.id
+    }
+}
+
+/// Return the current version
+pub fn version() -> Version {
+    let ffi_version = lief_ffi::version();
+    Version {
+        major: ffi_version.major, minor: ffi_version.minor,
+        patch: ffi_version.patch, id: ffi_version.id
+    }
+}
+
 /// Try to demangle the given input.
 ///
 /// This function requires the extended version of LIEF
@@ -131,3 +167,28 @@ pub fn demangle(mangled: &str) -> Result<String, Error> {
         |e: cxx::UniquePtr<cxx::String>| { e.to_string() }
     );
 }
+
+/// Hexdump the provided buffer.
+///
+/// For instance:
+///
+/// ```text
+/// +---------------------------------------------------------------------+
+/// | 88 56 05 00 00 00 00 00 00 00 00 00 22 58 05 00  | .V.........."X.. |
+/// | 10 71 02 00 78 55 05 00 00 00 00 00 00 00 00 00  | .q..xU.......... |
+/// | 68 5c 05 00 00 70 02 00 00 00 00 00 00 00 00 00  | h\...p.......... |
+/// | 00 00 00 00 00 00 00 00 00 00 00 00              | ............     |
+/// +---------------------------------------------------------------------+
+/// ```
+pub fn dump(buffer: &[u8]) -> String {
+    unsafe {
+        lief_ffi::dump(buffer.as_ptr(), buffer.len()).to_string()
+    }
+}
+
+/// Same as [`dump`] but with a limit on the number of bytes to dump
+pub fn dump_with_limit(buffer: &[u8], limit: u64) -> String {
+    unsafe {
+        lief_ffi::dump_with_limit(buffer.as_ptr(), buffer.len(), limit).to_string()
+    }
+}
