@@ -1,4 +1,4 @@
-/* Copyright 2024 R. Thomas
+/* Copyright 2024 - 2025 R. Thomas
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,8 +22,16 @@ class ELF_SymbolVersion : private Mirror<LIEF::ELF::SymbolVersion> {
   using lief_t = LIEF::ELF::SymbolVersion;
   using Mirror::Mirror;
 
-  uint16_t value() const { return get().value();  }
+  auto value() const { return get().value();  }
+
   auto symbol_version_auxiliary() const {
     return details::try_unique<ELF_SymbolVersionAux>(get().symbol_version_auxiliary());
   }
+
+  auto drop_version(uint16_t value) {
+    get().drop_version(value);
+  }
+
+  auto as_local() { get().as_local(); }
+  auto as_global() { get().as_global(); }
 };
