@@ -1,6 +1,5 @@
-/* Copyright 2017 - 2023 R. Thomas
-* Copyright 2017 - 2023 Quarkslab
-* Copyright 2017 - 2021 K. Nakagawa
+/* Copyright 2017 - 2025 R. Thomas
+* Copyright 2017 - 2025 Quarkslab
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -52,7 +51,6 @@ LIEF_PE_FORWARD(RelocationEntry)
 LIEF_PE_FORWARD(Export)
 LIEF_PE_FORWARD(ExportEntry)
 LIEF_PE_FORWARD(TLS)
-LIEF_PE_FORWARD(Symbol)
 LIEF_PE_FORWARD(Debug)
 LIEF_PE_FORWARD(CodeView)
 LIEF_PE_FORWARD(CodeViewPDB)
@@ -64,12 +62,10 @@ LIEF_PE_FORWARD(ResourceDirectory)
 LIEF_PE_FORWARD(ResourcesManager)
 LIEF_PE_FORWARD(ResourceVersion)
 LIEF_PE_FORWARD(ResourceStringFileInfo)
-LIEF_PE_FORWARD(ResourceFixedFileInfo)
 LIEF_PE_FORWARD(ResourceVarFileInfo)
-LIEF_PE_FORWARD(LangCodeItem)
 LIEF_PE_FORWARD(ResourceIcon)
-LIEF_PE_FORWARD(ResourceDialog)
-LIEF_PE_FORWARD(ResourceDialogItem)
+LIEF_PE_FORWARD(ResourceDialogExtended)
+LIEF_PE_FORWARD(ResourceDialogRegular)
 LIEF_PE_FORWARD(ResourceStringTable)
 LIEF_PE_FORWARD(ResourceAccelerator)
 
@@ -77,34 +73,28 @@ LIEF_PE_FORWARD(Signature)
 LIEF_PE_FORWARD(x509)
 LIEF_PE_FORWARD(SignerInfo)
 LIEF_PE_FORWARD(ContentInfo)
+LIEF_PE_FORWARD(GenericContent)
+LIEF_PE_FORWARD(SpcIndirectData)
 LIEF_PE_FORWARD(Attribute)
 LIEF_PE_FORWARD(ContentType)
 LIEF_PE_FORWARD(GenericType)
-//LIEF_PE_FORWARD(MsCounterSign)
+LIEF_PE_FORWARD(MsCounterSign)
 LIEF_PE_FORWARD(MsSpcNestedSignature)
 LIEF_PE_FORWARD(MsSpcStatementType)
+LIEF_PE_FORWARD(MsManifestBinaryID)
 LIEF_PE_FORWARD(PKCS9AtSequenceNumber)
 LIEF_PE_FORWARD(PKCS9CounterSignature)
 LIEF_PE_FORWARD(PKCS9MessageDigest)
 LIEF_PE_FORWARD(PKCS9SigningTime)
 LIEF_PE_FORWARD(SpcSpOpusInfo)
+LIEF_PE_FORWARD(SigningCertificateV2)
+LIEF_PE_FORWARD(SpcRelaxedPeMarkerCheck)
 
 LIEF_PE_FORWARD(CodeIntegrity)
 LIEF_PE_FORWARD(LoadConfiguration)
-LIEF_PE_FORWARD(LoadConfigurationV0)
-LIEF_PE_FORWARD(LoadConfigurationV1)
-LIEF_PE_FORWARD(LoadConfigurationV2)
-LIEF_PE_FORWARD(LoadConfigurationV3)
-LIEF_PE_FORWARD(LoadConfigurationV4)
-LIEF_PE_FORWARD(LoadConfigurationV5)
-LIEF_PE_FORWARD(LoadConfigurationV6)
-LIEF_PE_FORWARD(LoadConfigurationV7)
-LIEF_PE_FORWARD(LoadConfigurationV8)
-LIEF_PE_FORWARD(LoadConfigurationV9)
-LIEF_PE_FORWARD(LoadConfigurationV10)
-LIEF_PE_FORWARD(LoadConfigurationV11)
 LIEF_PE_FORWARD(Pogo)
 LIEF_PE_FORWARD(PogoEntry)
+LIEF_PE_FORWARD(Repro)
 
 // ELF
 // ==================================
@@ -127,9 +117,10 @@ LIEF_ELF_FORWARD(SymbolVersionDefinition)
 LIEF_ELF_FORWARD(SymbolVersionAux)
 LIEF_ELF_FORWARD(SymbolVersionAuxRequirement)
 LIEF_ELF_FORWARD(Note)
-LIEF_ELF_FORWARD(NoteDetails)
-LIEF_ELF_FORWARD(AndroidNote)
+LIEF_ELF_FORWARD(AndroidIdent)
+LIEF_ELF_FORWARD(QNXStack)
 LIEF_ELF_FORWARD(NoteAbi)
+LIEF_ELF_FORWARD(NoteGnuProperty)
 LIEF_ELF_FORWARD(CorePrPsInfo)
 LIEF_ELF_FORWARD(CorePrStatus)
 LIEF_ELF_FORWARD(CoreAuxv)
@@ -149,6 +140,7 @@ LIEF_MACHO_FORWARD(SymbolCommand)
 LIEF_MACHO_FORWARD(SegmentCommand)
 LIEF_MACHO_FORWARD(Section)
 LIEF_MACHO_FORWARD(MainCommand)
+LIEF_MACHO_FORWARD(NoteCommand)
 LIEF_MACHO_FORWARD(DynamicSymbolCommand)
 LIEF_MACHO_FORWARD(DylinkerCommand)
 LIEF_MACHO_FORWARD(DylibCommand)
@@ -172,6 +164,7 @@ LIEF_MACHO_FORWARD(SourceVersion)
 LIEF_MACHO_FORWARD(VersionMin)
 LIEF_MACHO_FORWARD(SegmentSplitInfo)
 LIEF_MACHO_FORWARD(SubFramework)
+LIEF_MACHO_FORWARD(Routine)
 LIEF_MACHO_FORWARD(DyldEnvironment)
 LIEF_MACHO_FORWARD(EncryptionInfo)
 LIEF_MACHO_FORWARD(BuildVersion)
@@ -180,6 +173,7 @@ LIEF_MACHO_FORWARD(FilesetCommand)
 LIEF_MACHO_FORWARD(TwoLevelHints)
 LIEF_MACHO_FORWARD(CodeSignatureDir)
 LIEF_MACHO_FORWARD(LinkerOptHint)
+LIEF_MACHO_FORWARD(UnknownCommand)
 
 // OAT
 // ===============================
@@ -228,22 +222,22 @@ class LIEF_API Visitor {
   // Abstract Part
   // =============
 
-  //! Method to visit a LIEF::Binary
+  /// Method to visit a LIEF::Binary
   LIEF_ABSTRACT_VISITABLE(Binary)
 
-  //! Method to visit a LIEF::Header
+  /// Method to visit a LIEF::Header
   LIEF_ABSTRACT_VISITABLE(Header)
 
-  //! Method to visit a LIEF::Section
+  /// Method to visit a LIEF::Section
   LIEF_ABSTRACT_VISITABLE(Section)
 
-  //! Method to visit a LIEF::Symbol
+  /// Method to visit a LIEF::Symbol
   LIEF_ABSTRACT_VISITABLE(Symbol)
 
-  //! Method to visit a LIEF::Relocation
+  /// Method to visit a LIEF::Relocation
   LIEF_ABSTRACT_VISITABLE(Relocation)
 
-  //! Method to visit a LIEF::Function
+  /// Method to visit a LIEF::Function
   LIEF_ABSTRACT_VISITABLE(Function)
 
   LIEF_ELF_VISITABLE(Binary)
@@ -265,9 +259,10 @@ class LIEF_API Visitor {
   LIEF_ELF_VISITABLE(SymbolVersionAux)
   LIEF_ELF_VISITABLE(SymbolVersionAuxRequirement)
   LIEF_ELF_VISITABLE(Note)
-  LIEF_ELF_VISITABLE(NoteDetails)
-  LIEF_ELF_VISITABLE(AndroidNote)
+  LIEF_ELF_VISITABLE(AndroidIdent)
+  LIEF_ELF_VISITABLE(QNXStack)
   LIEF_ELF_VISITABLE(NoteAbi)
+  LIEF_ELF_VISITABLE(NoteGnuProperty)
   LIEF_ELF_VISITABLE(CorePrPsInfo)
   LIEF_ELF_VISITABLE(CorePrStatus)
   LIEF_ELF_VISITABLE(CoreAuxv)
@@ -278,391 +273,373 @@ class LIEF_API Visitor {
 
   // PE Part
   // =======
-  //! Method to visit a LIEF::PE::Binary
+  /// Method to visit a LIEF::PE::Binary
   LIEF_PE_VISITABLE(Binary)
 
-  //! Method to visit a LIEF::PE::DosHeader
+  /// Method to visit a LIEF::PE::DosHeader
   LIEF_PE_VISITABLE(DosHeader)
 
-  //! Method to visit a LIEF::PE:RichHeader
+  /// Method to visit a LIEF::PE:RichHeader
   LIEF_PE_VISITABLE(RichHeader)
 
-  //! Method to visit a LIEF::PE:RichEntry
+  /// Method to visit a LIEF::PE:RichEntry
   LIEF_PE_VISITABLE(RichEntry)
 
-  //! Method to visit a LIEF::PE::Header
+  /// Method to visit a LIEF::PE::Header
   LIEF_PE_VISITABLE(Header)
 
-  //! Method to visit a LIEF::PE::OptionalHeader
+  /// Method to visit a LIEF::PE::OptionalHeader
   LIEF_PE_VISITABLE(OptionalHeader)
 
-  //! Method to visit a LIEF::PE::DataDirectory
+  /// Method to visit a LIEF::PE::DataDirectory
   LIEF_PE_VISITABLE(DataDirectory)
 
-  //! Method to visit a LIEF::PE::TLS
+  /// Method to visit a LIEF::PE::TLS
   LIEF_PE_VISITABLE(TLS)
 
-  //! Method to visit a LIEF::PE::Symbol
-  LIEF_PE_VISITABLE(Symbol)
-
-  //! Method to visit a LIEF::PE::Section
+  /// Method to visit a LIEF::PE::Section
   LIEF_PE_VISITABLE(Section)
 
-  //! Method to visit a LIEF::PE::Relocation
+  /// Method to visit a LIEF::PE::Relocation
   LIEF_PE_VISITABLE(Relocation)
 
-  //! Method to visit a LIEF::PE::RelocationEntry
+  /// Method to visit a LIEF::PE::RelocationEntry
   LIEF_PE_VISITABLE(RelocationEntry)
 
-  //! Method to visit a LIEF::PE::Export
+  /// Method to visit a LIEF::PE::Export
   LIEF_PE_VISITABLE(Export)
 
-  //! Method to visit a LIEF::PE::ExportEntry
+  /// Method to visit a LIEF::PE::ExportEntry
   LIEF_PE_VISITABLE(ExportEntry)
 
-  //! Method to visit a LIEF::PE::Debug
+  /// Method to visit a LIEF::PE::Debug
   LIEF_PE_VISITABLE(Debug)
 
-  //! Method to visit a LIEF::PE::CodeView
+  /// Method to visit a LIEF::PE::CodeView
   LIEF_PE_VISITABLE(CodeView)
 
-  //! Method to visit a LIEF::PE::CodeViewPDB
+  /// Method to visit a LIEF::PE::CodeViewPDB
   LIEF_PE_VISITABLE(CodeViewPDB)
 
-  //! Method to visit a LIEF::PE::Import
+  /// Method to visit a LIEF::PE::Import
   LIEF_PE_VISITABLE(Import)
 
-  //! Method to visit a LIEF::PE::ImportEntry
+  /// Method to visit a LIEF::PE::ImportEntry
   LIEF_PE_VISITABLE(ImportEntry)
 
-  //! Method to visit a LIEF::PE::DelayImport
+  /// Method to visit a LIEF::PE::DelayImport
   LIEF_PE_VISITABLE(DelayImport)
 
-  //! Method to visit a LIEF::PE::DelayImportEntry
+  /// Method to visit a LIEF::PE::DelayImportEntry
   LIEF_PE_VISITABLE(DelayImportEntry)
 
-  //! Method to visit a LIEF::PE::ResourceNode
+  /// Method to visit a LIEF::PE::ResourceNode
   LIEF_PE_VISITABLE(ResourceNode)
 
-  //! Method to visit a LIEF::PE::ResourceData
+  /// Method to visit a LIEF::PE::ResourceData
   LIEF_PE_VISITABLE(ResourceData)
 
-  //! Method to visit a LIEF::PE::ResourceDirectory
+  /// Method to visit a LIEF::PE::ResourceDirectory
   LIEF_PE_VISITABLE(ResourceDirectory)
 
-  //! Method to visit a LIEF::PE::ResourceVersion
+  /// Method to visit a LIEF::PE::ResourceVersion
   LIEF_PE_VISITABLE(ResourcesManager)
 
-  //! Method to visit a LIEF::PE::ResourceVersion
+  /// Method to visit a LIEF::PE::ResourceVersion
   LIEF_PE_VISITABLE(ResourceVersion)
 
-  //! Method to visit a LIEF::PE::ResourceStringFileInfo
+  /// Method to visit a LIEF::PE::ResourceStringFileInfo
   LIEF_PE_VISITABLE(ResourceStringFileInfo)
 
-  //! Method to visit a LIEF::PE::ResourceFixedFileInfo
-  LIEF_PE_VISITABLE(ResourceFixedFileInfo)
-
-  //! Method to visit a LIEF::PE::ResourceVarFileInfo
+  /// Method to visit a LIEF::PE::ResourceVarFileInfo
   LIEF_PE_VISITABLE(ResourceVarFileInfo)
 
-  //! Method to visit a LIEF::PE::ResourceStringTable
+  /// Method to visit a LIEF::PE::ResourceStringTable
   LIEF_PE_VISITABLE(ResourceStringTable)
 
-  //! Method to visit a LIEF::PE::ResourceAccelerator
+  /// Method to visit a LIEF::PE::ResourceAccelerator
   LIEF_PE_VISITABLE(ResourceAccelerator)
 
-  //! Method to visit a LIEF::PE::LangCodeItem
-  LIEF_PE_VISITABLE(LangCodeItem)
-
-  //! Method to visit a LIEF::PE::ResourceIcon
+  /// Method to visit a LIEF::PE::ResourceIcon
   LIEF_PE_VISITABLE(ResourceIcon)
 
-  //! Method to visit a LIEF::PE::ResourceDialog
-  LIEF_PE_VISITABLE(ResourceDialog)
+  /// Method to visit a LIEF::PE::ResourceDialogExtended
+  LIEF_PE_VISITABLE(ResourceDialogExtended)
 
-  //! Method to visit a LIEF::PE::ResourceDialogItem
-  LIEF_PE_VISITABLE(ResourceDialogItem)
+  /// Method to visit a LIEF::PE::ResourceDialogRegular
+  LIEF_PE_VISITABLE(ResourceDialogRegular)
 
-  //! Method to visit a LIEF::PE::Signature
+  /// Method to visit a LIEF::PE::Signature
   LIEF_PE_VISITABLE(Signature)
 
-  //! Method to visit a LIEF::PE::x509
+  /// Method to visit a LIEF::PE::x509
   LIEF_PE_VISITABLE(x509)
 
-  //! Method to visit a LIEF::PE::SignerInfo
+  /// Method to visit a LIEF::PE::SignerInfo
   LIEF_PE_VISITABLE(SignerInfo)
 
-  //! Method to visit a LIEF::PE::ContentInfo
+  /// Method to visit a LIEF::PE::ContentInfo
   LIEF_PE_VISITABLE(ContentInfo)
 
-  //! Method to visit a LIEF::PE::Attribute
+  /// Method to visit a LIEF::PE::Attribute
   LIEF_PE_VISITABLE(Attribute)
 
-  //! Method to visit a LIEF::PE::ContentType
+  /// Method to visit a LIEF::PE::ContentType
   LIEF_PE_VISITABLE(ContentType)
 
-  //! Method to visit a LIEF::PE::GenericType
+  /// Method to visit a LIEF::PE::GenericContent
+  LIEF_PE_VISITABLE(GenericContent)
+
+  /// Method to visit a LIEF::PE::SpcIndirectData
+  LIEF_PE_VISITABLE(SpcIndirectData)
+
+  /// Method to visit a LIEF::PE::GenericType
   LIEF_PE_VISITABLE(GenericType)
 
-  //! Method to visit a LIEF::PE::MsCounterSign
-  //LIEF_PE_VISITABLE(MsCounterSign)
+  /// Method to visit a LIEF::PE::MsCounterSign
+  LIEF_PE_VISITABLE(MsCounterSign)
 
-  //! Method to visit a LIEF::PE::MsSpcNestedSignature
+  /// Method to visit a LIEF::PE::MsManifestBinaryID
+  LIEF_PE_VISITABLE(MsManifestBinaryID)
+
+  /// Method to visit a LIEF::PE::MsSpcNestedSignature
   LIEF_PE_VISITABLE(MsSpcNestedSignature)
 
-  //! Method to visit a LIEF::PE::MsSpcStatementType
+  /// Method to visit a LIEF::PE::MsSpcStatementType
   LIEF_PE_VISITABLE(MsSpcStatementType)
 
-  //! Method to visit a LIEF::PE::PKCS9AtSequenceNumber
+  /// Method to visit a LIEF::PE::PKCS9AtSequenceNumber
   LIEF_PE_VISITABLE(PKCS9AtSequenceNumber)
 
-  //! Method to visit a LIEF::PE::PKCS9CounterSignature
+  /// Method to visit a LIEF::PE::PKCS9CounterSignature
   LIEF_PE_VISITABLE(PKCS9CounterSignature)
 
-  //! Method to visit a LIEF::PE::PKCS9MessageDigest
+  /// Method to visit a LIEF::PE::PKCS9MessageDigest
   LIEF_PE_VISITABLE(PKCS9MessageDigest)
 
-  //! Method to visit a LIEF::PE::PKCS9SigningTime
+  /// Method to visit a LIEF::PE::PKCS9SigningTime
   LIEF_PE_VISITABLE(PKCS9SigningTime)
 
-  //! Method to visit a LIEF::PE::SpcSpOpusInfo
+  /// Method to visit a LIEF::PE::SpcSpOpusInfo
   LIEF_PE_VISITABLE(SpcSpOpusInfo)
 
-  //! Method to visit a LIEF::PE::LoadConfiguration
+  /// Method to visit a LIEF::PE::SpcRelaxedPeMarkerCheck
+  LIEF_PE_VISITABLE(SpcRelaxedPeMarkerCheck)
+
+  /// Method to visit a LIEF::PE::SigningCertificateV2
+  LIEF_PE_VISITABLE(SigningCertificateV2)
+
+  /// Method to visit a LIEF::PE::LoadConfiguration
   LIEF_PE_VISITABLE(LoadConfiguration)
 
-  //! Method to visit a LIEF::PE::LoadConfigurationV0
-  LIEF_PE_VISITABLE(LoadConfigurationV0)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV1
-  LIEF_PE_VISITABLE(LoadConfigurationV1)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV2
-  LIEF_PE_VISITABLE(LoadConfigurationV2)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV3
-  LIEF_PE_VISITABLE(LoadConfigurationV3)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV4
-  LIEF_PE_VISITABLE(LoadConfigurationV4)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV5
-  LIEF_PE_VISITABLE(LoadConfigurationV5)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV6
-  LIEF_PE_VISITABLE(LoadConfigurationV6)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV7
-  LIEF_PE_VISITABLE(LoadConfigurationV7)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV8
-  LIEF_PE_VISITABLE(LoadConfigurationV8)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV9
-  LIEF_PE_VISITABLE(LoadConfigurationV9)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV10
-  LIEF_PE_VISITABLE(LoadConfigurationV10)
-
-  //! Method to visit a LIEF::PE::LoadConfigurationV11
-  LIEF_PE_VISITABLE(LoadConfigurationV11)
-
-  //! Method to visit a LIEF::PE::CodeIntegrity
+  /// Method to visit a LIEF::PE::CodeIntegrity
   LIEF_PE_VISITABLE(CodeIntegrity)
 
-  //! Method to visit a LIEF::PE::Pogo
+  /// Method to visit a LIEF::PE::Pogo
   LIEF_PE_VISITABLE(Pogo)
 
-  //! Method to visit a LIEF::PE::PogoEntry
+  /// Method to visit a LIEF::PE::PogoEntry
   LIEF_PE_VISITABLE(PogoEntry)
 
+  /// Method to visit a LIEF::PE::Repro
+  LIEF_PE_VISITABLE(Repro)
+
   // MachO part
   // ==========
-  //! Method to visit a LIEF::MachO::Binary
+  /// Method to visit a LIEF::MachO::Binary
   LIEF_MACHO_VISITABLE(Binary)
 
-  //! Method to visit a LIEF::MachO::Header
+  /// Method to visit a LIEF::MachO::Header
   LIEF_MACHO_VISITABLE(Header)
 
-  //! Method to visit a LIEF::MachO::LoadCommand
+  /// Method to visit a LIEF::MachO::LoadCommand
   LIEF_MACHO_VISITABLE(LoadCommand)
 
-  //! Method to visit a LIEF::MachO::UUIDCommand
+  /// Method to visit a LIEF::MachO::UUIDCommand
   LIEF_MACHO_VISITABLE(UUIDCommand)
 
-  //! Method to visit a LIEF::MachO::SymbolCommand
+  /// Method to visit a LIEF::MachO::SymbolCommand
   LIEF_MACHO_VISITABLE(SymbolCommand)
 
-  //! Method to visit a LIEF::MachO::SegmentCommand
+  /// Method to visit a LIEF::MachO::SegmentCommand
   LIEF_MACHO_VISITABLE(SegmentCommand)
 
-  //! Method to visit a LIEF::MachO::Section
+  /// Method to visit a LIEF::MachO::Section
   LIEF_MACHO_VISITABLE(Section)
 
-  //! Method to visit a LIEF::MachO::MainCommand
+  /// Method to visit a LIEF::MachO::MainCommand
   LIEF_MACHO_VISITABLE(MainCommand)
 
-  //! Method to visit a LIEF::MachO::DynamicSymbolCommand
+  /// Method to visit a LIEF::MachO::NoteCommand
+  LIEF_MACHO_VISITABLE(NoteCommand)
+
+  /// Method to visit a LIEF::MachO::DynamicSymbolCommand
   LIEF_MACHO_VISITABLE(DynamicSymbolCommand)
 
-  //! Method to visit a LIEF::MachO::DylinkerCommand
+  /// Method to visit a LIEF::MachO::DylinkerCommand
   LIEF_MACHO_VISITABLE(DylinkerCommand)
 
-  //! Method to visit a LIEF::MachO::DylibCommand
+  /// Method to visit a LIEF::MachO::DylibCommand
   LIEF_MACHO_VISITABLE(DylibCommand)
 
-  //! Method to visit a LIEF::MachO::ThreadCommand
+  /// Method to visit a LIEF::MachO::ThreadCommand
   LIEF_MACHO_VISITABLE(ThreadCommand)
 
-  //! Method to visit a LIEF::MachO::RPathCommand
+  /// Method to visit a LIEF::MachO::RPathCommand
   LIEF_MACHO_VISITABLE(RPathCommand)
 
-  //! Method to visit a LIEF::MachO::Symbol
+  /// Method to visit a LIEF::MachO::Symbol
   LIEF_MACHO_VISITABLE(Symbol)
 
-  //! Method to visit a LIEF::MachO::Relocation
+  /// Method to visit a LIEF::MachO::Relocation
   LIEF_MACHO_VISITABLE(Relocation)
 
-  //! Method to visit a LIEF::MachO::RelocationObject
+  /// Method to visit a LIEF::MachO::RelocationObject
   LIEF_MACHO_VISITABLE(RelocationObject)
 
-  //! Method to visit a LIEF::MachO::RelocationDyld
+  /// Method to visit a LIEF::MachO::RelocationDyld
   LIEF_MACHO_VISITABLE(RelocationDyld)
 
-  //! Method to visit a LIEF::MachO::RelocationFixup
+  /// Method to visit a LIEF::MachO::RelocationFixup
   LIEF_MACHO_VISITABLE(RelocationFixup)
 
-  //! Method to visit a LIEF::MachO::BindingInfo
+  /// Method to visit a LIEF::MachO::BindingInfo
   LIEF_MACHO_VISITABLE(BindingInfo)
 
-  //! Method to visit a LIEF::MachO::DyldBindingInfo
+  /// Method to visit a LIEF::MachO::DyldBindingInfo
   LIEF_MACHO_VISITABLE(DyldBindingInfo)
 
-  //! Method to visit a LIEF::MachO::ChainedBindingInfo
+  /// Method to visit a LIEF::MachO::ChainedBindingInfo
   LIEF_MACHO_VISITABLE(ChainedBindingInfo)
 
-  //! Method to visit a LIEF::MachO::DyldExportsTrie
+  /// Method to visit a LIEF::MachO::DyldExportsTrie
   LIEF_MACHO_VISITABLE(DyldExportsTrie)
 
-  //! Method to visit a LIEF::MachO::ExportInfo
+  /// Method to visit a LIEF::MachO::ExportInfo
   LIEF_MACHO_VISITABLE(ExportInfo)
 
-  //! @brief Method to visit a LIEF::MachO::FunctionStarts
+  /// Method to visit a LIEF::MachO::FunctionStarts
   LIEF_MACHO_VISITABLE(FunctionStarts)
 
-  //! @brief Method to visit a LIEF::MachO::CodeSignature
+  /// Method to visit a LIEF::MachO::CodeSignature
   LIEF_MACHO_VISITABLE(CodeSignature)
 
-  //! @brief Method to visit a LIEF::MachO::DataInCode
+  /// Method to visit a LIEF::MachO::DataInCode
   LIEF_MACHO_VISITABLE(DataInCode)
 
-  //! @brief Method to visit a LIEF::MachO::DataCodeEntry
+  /// Method to visit a LIEF::MachO::DataCodeEntry
   LIEF_MACHO_VISITABLE(DataCodeEntry)
 
-  //! @brief Method to visit a LIEF::MachO::SourceVersion
+  /// Method to visit a LIEF::MachO::SourceVersion
   LIEF_MACHO_VISITABLE(SourceVersion)
 
-  //! @brief Method to visit a LIEF::MachO::VersionMin
+  /// Method to visit a LIEF::MachO::VersionMin
   LIEF_MACHO_VISITABLE(VersionMin)
 
-  //! @brief Method to visit a LIEF::MachO::SegmentSplitInfo
+  /// Method to visit a LIEF::MachO::SegmentSplitInfo
   LIEF_MACHO_VISITABLE(SegmentSplitInfo)
 
-  //! @brief Method to visit a LIEF::MachO::SubFramework
+  /// Method to visit a LIEF::MachO::SubFramework
   LIEF_MACHO_VISITABLE(SubFramework)
 
-  //! @brief Method to visit a LIEF::MachO::DyldEnvironment
+  /// Method to visit a LIEF::MachO::Routine
+  LIEF_MACHO_VISITABLE(Routine)
+
+  /// Method to visit a LIEF::MachO::DyldEnvironment
   LIEF_MACHO_VISITABLE(DyldEnvironment)
 
-  //! @brief Method to visit a LIEF::MachO::DyldEnvironment
+  /// Method to visit a LIEF::MachO::DyldEnvironment
   LIEF_MACHO_VISITABLE(EncryptionInfo)
 
-  //! @brief Method to visit a LIEF::MachO:BuildVersion:
+  /// Method to visit a LIEF::MachO:BuildVersion:
   LIEF_MACHO_VISITABLE(BuildVersion)
 
-  //! @brief Method to visit a LIEF::MachO:BuildToolVersion:
+  /// Method to visit a LIEF::MachO:BuildToolVersion:
   LIEF_MACHO_VISITABLE(BuildToolVersion)
 
-  //! @brief Method to visit a LIEF::MachO:BuildToolVersion:
+  /// Method to visit a LIEF::MachO:BuildToolVersion:
   LIEF_MACHO_VISITABLE(FilesetCommand)
 
-  //! Method to visit a LIEF::MachO::CodeSignatureDir
+  /// Method to visit a LIEF::MachO::CodeSignatureDir
   LIEF_MACHO_VISITABLE(CodeSignatureDir)
 
-  //! Method to visit a LIEF::MachO::TwoLevelHints
+  /// Method to visit a LIEF::MachO::TwoLevelHints
   LIEF_MACHO_VISITABLE(TwoLevelHints)
 
-  //! Method to visit a LIEF::MachO::LinkerOptHint
+  /// Method to visit a LIEF::MachO::LinkerOptHint
   LIEF_MACHO_VISITABLE(LinkerOptHint)
 
+  /// Method to visit a LIEF::MachO::UnknownCommand
+  LIEF_MACHO_VISITABLE(UnknownCommand)
+
   // OAT part
   // ========
 
-  //! Method to visit a LIEF::OAT::Binary
+  /// Method to visit a LIEF::OAT::Binary
   LIEF_OAT_VISITABLE(Binary)
 
-  //! Method to visit a LIEF::OAT::Header
+  /// Method to visit a LIEF::OAT::Header
   LIEF_OAT_VISITABLE(Header)
 
-  //! Method to visit a LIEF::OAT::DexFile
+  /// Method to visit a LIEF::OAT::DexFile
   LIEF_OAT_VISITABLE(DexFile)
 
-  //! Method to visit a LIEF::OAT::Class
+  /// Method to visit a LIEF::OAT::Class
   LIEF_OAT_VISITABLE(Class)
 
-  //! Method to visit a LIEF::OAT::Method
+  /// Method to visit a LIEF::OAT::Method
   LIEF_OAT_VISITABLE(Method)
 
 
   // DEX part
   // ========
 
-  //! Method to visit a LIEF::DEX::File
+  /// Method to visit a LIEF::DEX::File
   LIEF_DEX_VISITABLE(File)
 
-//! Method to visit a LIEF::DEX::Field
+/// Method to visit a LIEF::DEX::Field
   LIEF_DEX_VISITABLE(Field)
 
-  //! Method to visit a LIEF::DEX::Method
+  /// Method to visit a LIEF::DEX::Method
   LIEF_DEX_VISITABLE(Method)
 
-  //! Method to visit a LIEF::DEX::Header
+  /// Method to visit a LIEF::DEX::Header
   LIEF_DEX_VISITABLE(Header)
 
-  //! Method to visit a LIEF::DEX::Class
+  /// Method to visit a LIEF::DEX::Class
   LIEF_DEX_VISITABLE(Class)
 
-  //! Method to visit a LIEF::DEX::CodeInfo
+  /// Method to visit a LIEF::DEX::CodeInfo
   LIEF_DEX_VISITABLE(CodeInfo)
 
-  //! Method to visit a LIEF::DEX::Type
+  /// Method to visit a LIEF::DEX::Type
   LIEF_DEX_VISITABLE(Type)
 
-  //! Method to visit a LIEF::DEX:Prototype:
+  /// Method to visit a LIEF::DEX:Prototype:
   LIEF_DEX_VISITABLE(Prototype)
 
-  //! Method to visit a LIEF::DEX:MapList:
+  /// Method to visit a LIEF::DEX:MapList:
   LIEF_DEX_VISITABLE(MapList)
 
-  //! Method to visit a LIEF::DEX:MapItem:
+  /// Method to visit a LIEF::DEX:MapItem:
   LIEF_DEX_VISITABLE(MapItem)
 
   // VDEX part
   // =========
 
-  //! Method to visit a LIEF::VDEX::File
+  /// Method to visit a LIEF::VDEX::File
   LIEF_VDEX_VISITABLE(File)
 
-  //! Method to visit a LIEF::VDEX::Header
+  /// Method to visit a LIEF::VDEX::Header
   LIEF_VDEX_VISITABLE(Header)
 
   // ART part
   // =========
 
-  //! Method to visit a LIEF::ART::File
+  /// Method to visit a LIEF::ART::File
   LIEF_ART_VISITABLE(File)
 
-  //! Method to visit a LIEF::ART::Header
+  /// Method to visit a LIEF::ART::Header
   LIEF_ART_VISITABLE(Header)
 
   template<class T>
@@ -683,7 +660,7 @@ void Visitor::operator()(Arg1&& arg1, Args&&... args) {
 
 template<class T>
 void Visitor::dispatch(const T& obj) {
-  size_t hash = reinterpret_cast<size_t>(&obj);
+  auto hash = reinterpret_cast<size_t>(&obj);
   if (visited_.find(hash) != std::end(visited_)) {
     // Already visited
     return;
