@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -108,6 +108,10 @@ Prototype* Method::prototype() {
   return const_cast<Prototype*>(static_cast<const Method*>(this)->prototype());
 }
 
+const CodeInfo& Method::code_info() const {
+  return code_info_;
+}
+
 void Method::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
