@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -283,8 +283,8 @@ const char* to_string(Section::TYPE e) {
     ENTRY(REGULAR),
     ENTRY(ZEROFILL),
     ENTRY(CSTRING_LITERALS),
-    ENTRY(S_4BYTE_LITERALS),
-    ENTRY(S_8BYTE_LITERALS),
+    ENTRY(IS_4BYTE_LITERALS),
+    ENTRY(IS_8BYTE_LITERALS),
     ENTRY(LITERAL_POINTERS),
     ENTRY(NON_LAZY_SYMBOL_POINTERS),
     ENTRY(LAZY_SYMBOL_POINTERS),
@@ -294,7 +294,7 @@ const char* to_string(Section::TYPE e) {
     ENTRY(COALESCED),
     ENTRY(GB_ZEROFILL),
     ENTRY(INTERPOSING),
-    ENTRY(S_16BYTE_LITERALS),
+    ENTRY(IS_16BYTE_LITERALS),
     ENTRY(DTRACE_DOF),
     ENTRY(LAZY_DYLIB_SYMBOL_POINTERS),
     ENTRY(THREAD_LOCAL_REGULAR),
