@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,10 +23,6 @@
 #include "frozen.hpp"
 #include "logging.hpp"
 
-#define LIEF_PE_FORCE_UNDEF
-#include "LIEF/PE/undef.h"
-
-#include "PE/Structures.hpp"
 #include "hash_stream.hpp"
 
 namespace LIEF {
@@ -37,11 +33,10 @@ void RichHeader::accept(LIEF::Visitor& visitor) const {
 }
 
 std::vector<uint8_t> RichHeader::raw(uint32_t xor_key) const {
-  static constexpr uint32_t RICH_MAGIC = 0x68636952;
   vector_iostream wstream;
 
   wstream
-    .write(details::DanS_Magic_number ^ xor_key)
+    .write(DANS_MAGIC_NUMBER ^ xor_key)
     /*
      * The first chunk needs to be aligned on 64-bit and padded
      * with 0-xor. We can't use vector_iostream::align as it would not
@@ -57,9 +52,8 @@ std::vector<uint8_t> RichHeader::raw(uint32_t xor_key) const {
     wstream
       .write(value ^ xor_key).write(entry.count() ^ xor_key);
   }
-
   wstream
-    .write(RICH_MAGIC).write(xor_key);
+    .write(RICH_MAGIC, std::size(RICH_MAGIC)).write(xor_key);
 
   return wstream.raw();
 }
@@ -87,9 +81,11 @@ std::vector<uint8_t> RichHeader::hash(ALGORITHMS algo, uint32_t xor_key) const {
 }
 
 std::ostream& operator<<(std::ostream& os, const RichHeader& rich_header) {
-  os << "Key: " << std::hex << rich_header.key() << '\n';
+  using namespace fmt;
+  os << format("Key: 0x{:08x} ({} entries)\n", rich_header.key(),
+               rich_header.entries().size());
   for (const RichEntry& entry : rich_header.entries()) {
-    os << "  - " << entry << '\n';
+    os << "  " << entry << '\n';
   }
   return os;
 }
