@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,9 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+#include <sstream>
 #include "LIEF/PE/debug/Repro.hpp"
 #include "LIEF/Visitor.hpp"
 
+#include "internal_utils.hpp"
+
 #include <spdlog/fmt/fmt.h>
 #include <spdlog/fmt/ranges.h>
 
@@ -26,9 +29,15 @@ void Repro::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
 
-std::ostream& operator<<(std::ostream& os, const Repro& entry) {
-  os << fmt::format("Hash: {}", entry.hash());
-  return os;
+std::string Repro::to_string() const {
+  std::ostringstream os;
+  if (hash().empty()) {
+    os << "  Repro (empty hash)";
+  }
+
+  os << Debug::to_string() << '\n'
+     << fmt::format("  Repro: {}", to_hex(hash(), 19));
+  return os.str();
 }
 
 } // namespace PE
