@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 #ifndef LIEF_PRIVATE_LOGGING_H
 #define LIEF_PRIVATE_LOGGING_H
 #include <memory>
+#include <sstream>
 
 #include "LIEF/logging.hpp" // Public interface
 #include "LIEF/config.h"
@@ -48,12 +49,23 @@
     }                        \
   } while (false)
 
+#if defined (LIEF_LOGGING_DEBUG)
+#define LIEF_LOG_LOCATION()                             \
+  do {                                                  \
+    LIEF_DEBUG("{}:{}", __FUNCTION__, __LINE__); \
+  } while (false)
+#else
+#define LIEF_LOG_LOCATION()
+#endif
+
+
 namespace LIEF {
 namespace logging {
 
 class Logger {
   public:
   static constexpr auto DEFAULT_NAME = "LIEF";
+  using instances_t = std::unordered_map<std::string, Logger*>;
   Logger(const Logger&) = delete;
   Logger& operator=(const Logger&) = delete;
 
@@ -117,8 +129,20 @@ class Logger {
     }
   }
 
+  template <typename... Args>
+  void critial(const char *fmt, const Args &... args) {
+    if constexpr (lief_logging_support) {
+      sink_->critical(fmt::runtime(fmt), args...);
+    }
+  }
+
   void set_logger(std::shared_ptr<spdlog::logger> logger);
 
+  spdlog::logger& sink() {
+    assert(sink_ != nullptr);
+    return *sink_;
+  }
+
   ~Logger() = default;
   Logger() = delete;
   private:
@@ -128,8 +152,6 @@ class Logger {
   Logger(Logger&&) noexcept = default;
   Logger& operator=(Logger&&) noexcept = default;
 
-  static void destroy();
-  static inline std::unordered_map<std::string, Logger*> instances_;
   std::shared_ptr<spdlog::logger> sink_;
 };
 
@@ -166,6 +188,54 @@ inline void needs_lief_extended() {
   }
 }
 
+class Stream : public std::stringbuf {
+  public:
+  Stream(LEVEL lvl) :
+    lvl_(lvl)
+  {}
+
+  int sync() override {
+    switch (lvl_) {
+      case LEVEL::OFF:
+        break;
+
+      case LEVEL::TRACE:
+      case LEVEL::DEBUG:
+        {
+          LIEF_DEBUG("{}", str());
+          break;
+        }
+
+      case LEVEL::INFO:
+        {
+          LIEF_INFO("{}", str());
+          break;
+        }
+
+      case LEVEL::WARN:
+        {
+          LIEF_WARN("{}", str());
+          break;
+        }
+      case LEVEL::ERR:
+        {
+          LIEF_ERR("{}", str());
+          break;
+        }
+
+      case LEVEL::CRITICAL:
+        {
+          critical("{}", str());
+          break;
+        }
+    }
+    str("");
+    return 0;
+  }
+  protected:
+  LEVEL lvl_ = LEVEL::OFF;
+};
+
 }
 }
 
